pub struct InterruptHandler<T: Instance> { /* private fields */ }Expand description
WWDT interrupt handler.
This handler is called when the watchdog warning interrupt fires. When reset happens, the interrupt handler will never be reached.